==> alg-alg-1.9.1-20190227.015929-1-sources.jar: cn/com/duiba/nezha/alg/alg/vo/BudgetSmoothDo.java <==
package cn.com.duiba.nezha.alg.alg.vo;

import java.io.Serializable;


/**
 * 广告预算消耗信息
 */
public class BudgetSmoothDo implements Serializable {


    private Long budgetType;// 1：advert 2：orientation  3：orientation & app 4：orientation And Hours  5：orientation And Hour

    private Long timeType;// 1：hours 2：hour  3：day


    private Boolean isSmooth;


    private BudgetDo budgetDo;

    private Double timeRatio;

    private Double budgetRatio;

    private Double ratio;


    private BudgetDo lastBudgetDo;



    private Double currentTimeRatio;

    private Double currentBudgetRatio;

    private Double currentRatio;



    public Long getBudgetType() {
        return budgetType;
    }

    public void setBudgetType(Long budgetType) {
        this.budgetType = budgetType;
    }


    public Long getTimeType() {
        return timeType;
    }

    public void setTimeType(Long timeType) {
        this.timeType = timeType;
    }


    public Boolean getSmooth() {
        return isSmooth;
    }

    public void setSmooth(Boolean smooth) {
        isSmooth = smooth;
    }

    public BudgetDo getBudgetDo() {
        return budgetDo;
    }

    public void setBudgetDo(BudgetDo budgetDo) {
        this.budgetDo = budgetDo;
    }


    public Double getRatio() {
        return ratio;
    }

    public void setRatio(Double ratio) {
        this.ratio = ratio;
    }

    public Double getTimeRatio() {
        return timeRatio;
    }

    public void setTimeRatio(Double timeRatio) {
        this.timeRatio = timeRatio;
    }


    public Double getBudgetRatio() {
        return budgetRatio;
    }

    public void setBudgetRatio(Double budgetRatio) {
        this.budgetRatio = budgetRatio;
    }



    public Double getCurrentRatio() {
        return currentRatio;
    }

    public void setCurrentRatio(Double currentRatio) {
        this.currentRatio = currentRatio;
    }

    public Double getCurrentTimeRatio() {
        return currentTimeRatio;
    }

    public void setCurrentTimeRatio(Double currentTimeRatio) {
        this.currentTimeRatio = currentTimeRatio;
    }

    public Double getCurrentBudgetRatio() {
        return currentBudgetRatio;
    }

    public void setCurrentBudgetRatio(Double currentBudgetRatio) {
        this.currentBudgetRatio = currentBudgetRatio;
    }

    public Boolean getIsSmooth() {
        return isSmooth;
    }

    public void setIsSmooth(Boolean isSmooth) {
        isSmooth = isSmooth;
    }

    public BudgetDo getLastBudgetDo() {
        return lastBudgetDo;
    }

    public void setLastBudgetDo(BudgetDo lastBudgetDo) {
        this.lastBudgetDo = lastBudgetDo;
    }
}

==> alg-alg-1.11.4-20190506.020625-1-sources.jar: cn/com/duiba/nezha/alg/alg/vo/BudgetSmoothDo.java <==
package cn.com.duiba.nezha.alg.alg.vo;

import java.io.Serializable;


/**
 * 广告预算消耗信息
 */
public class BudgetSmoothDo implements Serializable {


    private Long budgetType;// 1：advert 2：orientation  3：orientation & app 4：orientation And Hours  5：orientation And Hour

    private Long timeType;// 1：hours 2：hour  3：day


    private Boolean needSmooth;


    private BudgetDo budgetDo;

    private Double timeRatio;

    private Double budgetRatio;

    private Double ratio;


    private Boolean currentValid;

    private Double currentTimeRatio;

    private Double currentBudgetRatio;

    private Double currentRatio;


    private Double smoothFactor;

    private long times;

    private Boolean valid;


    public Long getBudgetType() {
        return budgetType;
    }

    public void setBudgetType(Long budgetType) {
        this.budgetType = budgetType;
    }


    public Long getTimeType() {
        return timeType;
    }

    public void setTimeType(Long timeType) {
        this.timeType = timeType;
    }


    public Boolean getNeedSmooth() {
        return needSmooth;
    }

    public void setNeedSmooth(Boolean needSmooth) {
        this.needSmooth = needSmooth;
    }

    public BudgetDo getBudgetDo() {
        return budgetDo;
    }

    public void setBudgetDo(BudgetDo budgetDo) {
        this.budgetDo = budgetDo;
    }


    public Double getRatio() {
        return ratio;
    }

    public void setRatio(Double ratio) {
        this.ratio = ratio;
    }

    public Double getTimeRatio() {
        return timeRatio;
    }

    public void setTimeRatio(Double timeRatio) {
        this.timeRatio = timeRatio;
    }


    public Double getBudgetRatio() {
        return budgetRatio;
    }

    public void setBudgetRatio(Double budgetRatio) {
        this.budgetRatio = budgetRatio;
    }



    public Double getCurrentRatio() {
        return currentRatio;
    }

    public void setCurrentRatio(Double currentRatio) {
        this.currentRatio = currentRatio;
    }

    public Double getCurrentTimeRatio() {
        return currentTimeRatio;
    }

    public void setCurrentTimeRatio(Double currentTimeRatio) {
        this.currentTimeRatio = currentTimeRatio;
    }

    public Double getCurrentBudgetRatio() {
        return currentBudgetRatio;
    }

    public void setCurrentBudgetRatio(Double currentBudgetRatio) {
        this.currentBudgetRatio = currentBudgetRatio;
    }


    public Double getSmoothFactor() {
        return smoothFactor;
    }

    public void setSmoothFactor(Double smoothFactor) {
        this.smoothFactor = smoothFactor;
    }

    public Boolean getCurrentValid() {
        return currentValid;
    }

    public void setCurrentValid(Boolean currentValid) {
        this.currentValid = currentValid;
    }


    public Boolean getValid() {
        return valid;
    }
    public void setValid(Boolean valid) {
        this.valid = valid;
    }

    public long getTimes() {
        return times;
    }

    public void setTimes(long times) {
        this.times = times;
    }
}
